# Generated by Django 3.1.7 on 2021-03-26 22:00

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('notifications', '0003_notification_channels_json'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='notification',
            name='channels',
        )
    ]
