# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2017-07-19 11:37
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('notifications', '0002_auto_20170718_1539'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='notification',
            options={'ordering': ('create_date',)},
        ),
    ]
